# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from pyVmomi.vmodl import DynamicData

class SharedGpuCapabilities(DynamicData):
   vgpu: str
   diskSnapshotSupported: bool
   memorySnapshotSupported: bool
   suspendSupported: bool
   migrateSupported: bool
