# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

class VsanHclMinFwConstraint(DynamicData):
   vcgId: int
   vcgLink: str
   model: str
   partner: str
   partNumber: Optional[str] = None
   release: str
   firmware: str
