# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from pyVmomi.vim.fault import CpuIncompatible

class CpuIncompatible1ECX(CpuIncompatible):
   sse3: bool
   pclmulqdq: bool
   ssse3: bool
   sse41: bool
   sse42: bool
   aes: bool
   other: bool
   otherOnly: bool
