# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

class PropertyInfo(DynamicData):
   key: int
   classId: Optional[str] = None
   instanceId: Optional[str] = None
   id: Optional[str] = None
   category: Optional[str] = None
   label: Optional[str] = None
   type: Optional[str] = None
   typeReference: Optional[str] = None
   userConfigurable: Optional[bool] = None
   defaultValue: Optional[str] = None
   value: Optional[str] = None
   description: Optional[str] = None
