# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim import HostSystem

from pyVmomi.vmodl import DynamicData

class VsanVibSpec(DynamicData):
   host: HostSystem
   metaUrl: Optional[str] = None
   metaSha1Sum: Optional[str] = None
   vibUrl: str
   vibSha1Sum: str
