# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

class HostBusAdapter(DynamicData):
   key: Optional[str] = None
   device: str
   bus: int
   status: str
   model: str
   driver: Optional[str] = None
   pci: Optional[str] = None
   storageProtocol: Optional[str] = None
