# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from pyVmomi.vim.vm.device import VirtualDevice

class VirtualFloppy(VirtualDevice):
   class ImageBackingInfo(VirtualDevice.FileBackingInfo):
      pass

   class DeviceBackingInfo(VirtualDevice.DeviceBackingInfo):
      pass

   class RemoteDeviceBackingInfo(VirtualDevice.RemoteDeviceBackingInfo):
      pass
